Getting conda_envfile
=====================

Using conda
-----------

.. code-block:: none

  conda install -c conda-forge conda_envfile

Using PyPi
----------

.. code-block:: none

  python -m pip install conda_envfile

From source
-----------

.. code-block:: none

  git checkout https://github.com/tdegeus/conda_envfile.git
  cd conda_envfile

  python -m pip install .
